# Ssm Parameter Config

[![Checks][checks-shield]][checks-url]
[![Codecov][codecov-shield]][codecov-url]



[codecov-shield]: https://img.shields.io/codecov/c/github/mumblepins/ssm-parameter-config
[codecov-url]: https://app.codecov.io/gh/mumblepins/ssm-parameter-config

[checks-shield]: https://img.shields.io/github/workflow/status/mumblepins/ssm-parameter-config/Python%20Publish?style=flat-square
[checks-url]: https://github.com/mumblepins/ssm-parameter-config/actions/workflows/python-publish.yml
